netapp_ontap.models.counter_schema API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.counter_schema`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class CounterSchemaSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the CounterSchema object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `denominator: CounterDenominator GET`

    Counter used as the denominator in calculating the resulting value of averages and percentages.

  `description: str GET`

    Counter or property description.

  `name: str GET`

    Counter or property name.

  `type: str GET`

    Type of counter or property. Properties will always set this field to 'string'.

    Valid choices:

    - average
    - rate
    - raw
    - delta
    - percent
    - string
  `unit: str GET`

    Counter unit.

    Valid choices:

    - per_sec
    - b_per_sec
    - kb_per_sec
    - mb_per_sec
    - percent
    - millisec
    - microsec
    - nanosec
    - sec
    - none